<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>AntialiasingMode</name>
    <message>
        <location filename="../AntialiasingMode.js" line="+74"/>
        <source>&amp;Anti-aliasing</source>
        <translation>アンチエイリアス</translation>
    </message>
</context>
</TS>
